=====================
Vitrage Configuration
=====================

General
-------

.. toctree::
   :maxdepth: 1

   high-scale
   resource-state-config
   alarm-severity-config
   profiler-config
   keycloak-config

   ../configuration/index

Datasources
-----------

.. toctree::
   :maxdepth: 1

   nagios-config
   static-config
   zabbix_vitrage
   k8s_datasource
   nova-config
   prometheus-datasource
   kapacitor-datasource
   tmfapi639-datasource
   cetus_datasource


Notifiers
---------

.. toctree::
   :maxdepth: 1

   nova-notifier
   notifier-snmp-plugin
   mistral-config
   notifier-webhook-plugin
   zaqar_notifier


Machine_Learning
----------------

.. toctree::
   :maxdepth: 1

   ml-jaccard_correlation

